pub struct VirtualMemoryAnalysis<T = f32> { /* private fields */ }Expand description
Statistics about a memory optimization operation
Implementations
Sourceimpl<T> VirtualMemoryAnalysis<T>
impl<T> VirtualMemoryAnalysis<T>
pub fn new() -> Selfwhere
T: Default,
Sourcepub const fn features_before(&self) -> usize
pub const fn features_before(&self) -> usize
returns the number of features before optimization
Sourcepub fn features_before_mut(&mut self) -> &mut usize
pub fn features_before_mut(&mut self) -> &mut usize
returns a mutable reference to the number of features before optimization
Sourcepub const fn features_after(&self) -> usize
pub const fn features_after(&self) -> usize
returns the number of features after optimization
Sourcepub fn features_after_mut(&mut self) -> &mut usize
pub fn features_after_mut(&mut self) -> &mut usize
returns a mutable reference to the number of features after optimization
Sourcepub const fn pruned_count(&self) -> usize
pub const fn pruned_count(&self) -> usize
returns the number of features that were pruned
Sourcepub fn pruned_count_mut(&mut self) -> &mut usize
pub fn pruned_count_mut(&mut self) -> &mut usize
returns a mutable reference to the number of features that were pruned
Sourcepub const fn memory_pressure(&self) -> &T
pub const fn memory_pressure(&self) -> &T
returns the memory pressure metric (ratio of features to target)
Sourcepub fn memory_pressure_mut(&mut self) -> &mut T
pub fn memory_pressure_mut(&mut self) -> &mut T
returns a mutable reference to the memory pressure metric (ratio of features to target)
Sourcepub const fn importance_threshold(&self) -> &T
pub const fn importance_threshold(&self) -> &T
returns the importance threshold used for pruning
Sourcepub fn importance_threshold_mut(&mut self) -> &mut T
pub fn importance_threshold_mut(&mut self) -> &mut T
returns a mutable reference to the importance threshold used for pruning